// Lampeggio di due led: uno con il main e l'altro con TMR0+Int

#pragma config FOSC = XT        // Oscillator Selection bits (XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN)
#pragma config WDTE = OFF       // Watchdog Timer Enable bit (WDT disabled and can be enabled by SWDTEN bit of the WDTCON register)
#pragma config PWRTE = OFF      // Power-up Timer Enable bit (PWRT disabled)
#pragma config MCLRE = ON       // RE3/MCLR pin function select bit (RE3/MCLR pin function is MCLR)
#pragma config CP = OFF         // Code Protection bit (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Code Protection bit (Data memory code protection is disabled)
#pragma config BOREN = OFF      // Brown Out Reset Selection bits (BOR disabled)
#pragma config IESO = OFF       // Internal External Switchover bit (Internal/External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enabled bit (Fail-Safe Clock Monitor is disabled)
#pragma config LVP = OFF        // Low Voltage Programming Enable bit (RB3 pin has digital I/O, HV on MCLR must be used for programming)

// CONFIG2
#pragma config BOR4V = BOR40V   // Brown-out Reset Selection bit (Brown-out Reset set to 4.0V)
#pragma config WRT = OFF        // Flash Program Memory Self Write Enable bits (Write protection off)

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

#include <xc.h>                    //Header file generico
#define _XTAL_FREQ 8000000         //Specifico la frequenza dell'oscillatore

#define    TEMPOLED    125
#define    LED0        RD0
#define    LED1        RD1

void main(void) {

    PORTA = 0x00;
    PORTB = 0x00;    
    PORTC = 0x00;
    PORTD = 0x00;    
    PORTE = 0x00;
    
    TRISA = 0b00000000;             //Imposto i pin di PORTA 
    TRISB = 0b00000000;             //Imposto i pin di PORTB
    TRISC = 0b00000000;             //Imposto i pin di PORTC 
    TRISD = 0b00000000;             //Imposto i pin di PORTD 
    TRISE = 0b00000000;             //Imposto i pin di PORTE 

    ANSEL = 0x00;                   //Imposto tutti i pin come ingressi digitali
    ANSELH = 0x00;                  //Imposto tutti i pin come ingressi digitali
    
    
    OPTION_REG = 0b10000100;    // No pull-up PORTB,  Fosc/4,  PS=32
    INTCON = 0b10100000;        // Impostazione Interrupt su TMR0  GIE=T0IE=1
    TMR0 = 6;                   // Imposto Timer0 per un conteggio pari a 250
    
       
    while (1) {                       //Ciclo infinito
       
       LED1^=1;
       __delay_ms(1000);
    }

}

// L'interrupt mi permette di ottenere un lampeggio di LED0 pari a 0.5s

void interrupt ISR(void) // Interrupt Service Routine
 {
    char conta;
    
    if (INTCONbits.T0IE && INTCONbits.T0IF) // verifico che l'interrupt  stato 
       {                                    // causato da un overflow del TMR0
       TMR0 = 6;                // Ricarico TMR0 per un conteggio pari a 250
       INTCONbits.T0IF = 0;     // Resetto il flag di interrupt per TMR0
           
       conta++;                 // Incremento il conteggio per il lampeggio del LED1
       
       if (conta >= TEMPOLED)   // conta = 125?
          {
          LED0=~LED0;           // Inverto lo stato del led per farlo lampeggiare
          conta=0;              // Azzero il conteggio per ricominciare daccapo
          }
       } 
 } 